% B1AR module

function [k_kinetic, N_cT, K_C] = kinetic_parameters(M, include_type2_reactions, num_cols)
    % Set the kinetic rate constants.
    % original model had reactions that omitted enzymes as substrates e.g. BARK
    % convert unit from 1/s to 1/uM.s by dividing by conc of enzyme
    % all reactions were irreversible, made reversible by letting kr ~= 0

    
    % CONVERT TO fM 
    % oncentration of BARK = 0.6uM (crude approx from litsearch, for GRK)
    bigNum = 1e6;
    fastKineticConstant = bigNum;
    smallReverse = fastKineticConstant/(bigNum^2);
    u_to_f = 1e9;
    cBARK = 0.6*u_to_f;            %fM
    cPKACI = 0.0587898478276673*u_to_f;        %fM
    
    kB11p = 1.1e-3 / cBARK;      % 1/fM.s
    kB11m = 2.2e-3;             % 1/s
    kB12p = fastKineticConstant;%1/s
    kB12m = smallReverse;       % 1/fM.s
    kB21p = kB11p;              % 1/fM.s
    kB21m = kB11m;              % 1/s
    kB22p = fastKineticConstant;%1/s
    kB22m = smallReverse;       % 1/fM.s
    kP1p = 2.2e-3/ cPKACI;          % 1/fM.s (kp_kam)
    kP1m = smallReverse;        % 1/s
    kP2p = fastKineticConstant; % 1/s
    kP2m = 3.6e-3/u_to_f;   % 1/fM.s (kp_kap)
    
    % detailed balance for kP2p
    kP2p = kP2m*kP1m/kP1p;
    
    k_kinetic = [
        kB11p, kB12p, kB21p, kB22p, kP1p, kP2p,...
        kB11m, kB12m, kB21m, kB22m, kP1m, kP2m
        ]';

    % CONSTRAINTS
    N_cT = zeros(1,size(M,2)); 
    % substrate B1ARp is in eqlm with product B1ARtot
    N_cT(1,num_cols + 7) = 1;
    N_cT(1,num_cols + 8) = -1;

    Kc = ones(1,size(N_cT,1));

return 